//+------------------------------------------------------------------+
//+------------------------------------------------------------------+
#property copyright ""
#property link      ""
#property strict
#property indicator_separate_window
#property indicator_buffers 4
#property indicator_color1 Black
#property indicator_color2 Green
#property indicator_color3 Red
#property indicator_color4 Orange
#property indicator_levelwidth 4
#property indicator_width2  4
#property indicator_width2  4
#property indicator_width3  4
#property indicator_minimum 0
//--- input parameters
input int     MaPeriod1          = 5;
input int     MaPeriod2          = 10;
input int     MaPeriod3          = 20;
extern bool   alertsOn           = true;
extern bool   alertsOnCurrent    = true;
extern bool   alertsMessage      = true;
extern bool   alertsSound        = true;
extern bool   alertsEmail        = false;
extern bool   alertsNotificaton  = false;
extern string soundfile          = "alert2.wav";
extern bool   arrowsVisible      = false;
extern string arrowsIdentifier   = "emas Arrows1";
extern int    arrowsSize         = 1;
extern double arrowsDisplacement = 1.0;
extern color  arrowsUpColor      = LimeGreen;
extern color  arrowsDnColor      = Orange;
extern int    arrowsUpCode       = 241;
extern int    arrowsDownCode     = 242;

//Buffers
double Buffer1[];
double Buffer2[];
double Buffer3[];
double Buffer4[];
double trend[];
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int OnInit()
  {
//--- indicator buffers mapping
   IndicatorDigits(Digits);
   IndicatorBuffers(5);
   IndicatorShortName("EMAs(" + IntegerToString(MaPeriod1) + "," + IntegerToString(MaPeriod2) + "," + IntegerToString(MaPeriod3) + ")");
   SetIndexStyle(0,DRAW_NONE);
   SetIndexBuffer(0,Buffer1);
   SetIndexStyle(1,DRAW_HISTOGRAM);
   SetIndexBuffer(1,Buffer2);
   SetIndexStyle(2,DRAW_HISTOGRAM);
   SetIndexBuffer(2,Buffer3);
   SetIndexStyle(3,DRAW_HISTOGRAM);
   SetIndexBuffer(3,Buffer4);
   SetIndexBuffer(4,trend);
//---
   return(INIT_SUCCEEDED);
  }
int deinit()
{
   string lookFor       = arrowsIdentifier+":";
   int    lookForLength = StringLen(lookFor);
   for (int i=ObjectsTotal()-1; i>=0; i--)
   {
      string objectName = ObjectName(i);
         if (StringSubstr(objectName,0,lookForLength) == lookFor) ObjectDelete(objectName);
   }
   return(0); 
}
  
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int OnCalculate(const int rates_total,
                const int prev_calculated,
                const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tick_volume[],
                const long &volume[],
                const int &spread[])
  {
//---
   int    countedBars=prev_calculated;
   double ma1, ma2, ma3;
//----
   if(Bars<MaPeriod3)return(0);
   
   for(int i=Bars-countedBars-1; i>=0; i--){
      Buffer1[i]=0;
   
      ma1 = iMA(NULL,0,MaPeriod1,0,MODE_EMA,PRICE_CLOSE,i);
      ma2 = iMA(NULL,0,MaPeriod2,0,MODE_EMA,PRICE_CLOSE,i);
      ma3 = iMA(NULL,0,MaPeriod3,0,MODE_EMA,PRICE_CLOSE,i);
      
      if (i<Bars-1) trend[i] = 0;
      if(ma1>ma2 && ma2>ma3){ Buffer1[i]+=1; trend[i] =  1; }
      if(ma1<ma2 && ma2<ma3){ Buffer1[i]-=1; trend[i] = -1; }
      
      if(Buffer1[i]>0){
         Buffer2[i]=2;
         Buffer3[i]=EMPTY_VALUE;
         Buffer4[i]=EMPTY_VALUE;
      }else if(Buffer1[i]<0){
         Buffer2[i]=EMPTY_VALUE;
         Buffer3[i]=2;
         Buffer4[i]=EMPTY_VALUE;
      }else{
         Buffer2[i]=EMPTY_VALUE;
         Buffer3[i]=EMPTY_VALUE;
         Buffer4[i]=1.5;
      }
      manageArrow(i);
   }
   
//--- return value of prev_calculated for next call
  if (alertsOn)
  {
      int whichBar = 1; if (alertsOnCurrent) whichBar = 1;
      if (trend[whichBar] != trend[whichBar+1])
      {
         if (trend[whichBar] ==  1) doAlert("all EMAs alligned up");
         if (trend[whichBar] == -1) doAlert("all EMAs alligned down");       
      }         
  }
  return(rates_total);
}


//------------------------------------------------------------------
//
//------------------------------------------------------------------
//
//
//
//
//

void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[0]) {
          previousAlert  = doWhat;
          previousTime   = Time[0];

          //
          //
          //
          //
          //

          message =  StringConcatenate(Symbol(),Period()," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," emas ",doWhat);
             if (alertsMessage)     Alert(message);
             if (alertsEmail)       SendMail(StringConcatenate(Symbol()," emas "),message);
             if (alertsNotificaton) SendNotification(StringConcatenate(Symbol()," emas ",message));
             if (alertsSound)       PlaySound(soundfile);
      }
}

//------------------------------------------------------------------
//
//------------------------------------------------------------------
//
//
//
//
//

void manageArrow(int i)
{
   if (arrowsVisible)
   {
      ObjectDelete(arrowsIdentifier+":"+(string)Time[i]);
      if (i <(Bars-1) && trend[i]!=trend[i+1])
      {
         if (trend[i] == 1) drawArrow(i,arrowsUpColor,arrowsUpCode  ,false);
         if (trend[i] ==-1) drawArrow(i,arrowsDnColor,arrowsDownCode,true);
      }
   }
}               

void drawArrow(int i,color theColor,int theCode,bool up)
{
   string name = arrowsIdentifier+":"+(string)Time[i];
   double gap  = iATR(NULL,0,20,i);   
   
      //
      //
      //
      //
      //
      
      ObjectCreate(name,OBJ_ARROW,0,Time[i],0);
         ObjectSet(name,OBJPROP_ARROWCODE,theCode);
         ObjectSet(name,OBJPROP_COLOR,theColor);
         ObjectSet(name,OBJPROP_WIDTH,arrowsSize);
         if (up)
               ObjectSet(name,OBJPROP_PRICE1,High[i] + arrowsDisplacement * gap);
         else  ObjectSet(name,OBJPROP_PRICE1,Low[i]  - arrowsDisplacement * gap);
}